@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Minting profile for Plicease
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 
 with qw( Dist::Zilla::Role::MintingProfile::ShareDir );
@@ -26,7 +26,7 @@ Dist::Zilla::MintingProfile::Author::Plicease - Minting profile for Plicease
 
 =head1 VERSION
 
-version 1.74
+version 1.75
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ This is the normal minting profile used by Plicease.
 
 =head1 AUTHOR
 
-Graham Ollis <perl@cpan.org>
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
