@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -312,7 +312,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.74
+version 1.75
 
 =head1 DESCRIPTION
 
@@ -320,7 +320,7 @@ Create a dist in plicease style.
 
 =head1 AUTHOR
 
-Graham Ollis <perl@cpan.org>
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
