@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -120,7 +120,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 1.74
+version 1.75
 
 =head1 SYNOPSIS
 
@@ -208,7 +208,7 @@ Recommended if Mojolicious or AnyEvent modules are required.
 
 =head1 AUTHOR
 
-Graham Ollis <perl@cpan.org>
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
