@@ -9,7 +9,7 @@ with 'Dist::Zilla::Role::FileFinderUser' => {
 };
 
 # ABSTRACT: munge the AUTHOR section
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 
 has original => (
@@ -102,7 +102,7 @@ Dist::Zilla::Plugin::Author::Plicease::Thanks - munge the AUTHOR section
 
 =head1 VERSION
 
-version 1.74
+version 1.75
 
 =head1 SYNOPSIS
 
@@ -124,7 +124,7 @@ version 1.74
 
 =head1 AUTHOR
 
-Graham Ollis <perl@cpan.org>
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
